==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Input/wavpack/translations/wavpack_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="cs">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="28"/>
        <source>WavPack Plugin</source>
        <translation>Modul WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="89"/>
        <source>About WavPack Audio Plugin</source>
        <translation>O modulu WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="90"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Vstupní modul Qmmp WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="92"/>
        <source>WavPack library version:</source>
        <translation>Verze knihovny WavPack:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="93"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="30"/>
        <source>WavPack Files</source>
        <translation>Soubory WavPack</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="73"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="68"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="75"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="198"/>
        <source>APE Tag</source>
        <translation>Tag APE</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>Cesta k souboru:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="169"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="65"/>
        <source>Sample rate:</source>
        <translation>Vzorkovací frekvence:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="82"/>
        <source>File size:</source>
        <translation>Velikost souboru:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="298"/>
        <source>Title:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="288"/>
        <source>Artist:</source>
        <translation>Umělec:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="278"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="268"/>
        <source>Comment:</source>
        <translation>Komentář:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="248"/>
        <source>Year:</source>
        <translation>Rok:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="235"/>
        <source>Track number:</source>
        <translation>Číslo stopy:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="258"/>
        <source>Genre:</source>
        <translation>Žánr:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="225"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="339"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="48"/>
        <source>Length:</source>
        <translation>Délka:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="102"/>
        <source>Channels:</source>
        <translation>Počet kanálů:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>WavPack Info</source>
        <translation>Informace WavPack</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="125"/>
        <source>Bitrate:</source>
        <translation>Datový tok:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="142"/>
        <source>Ratio:</source>
        <translation>Poměr:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="159"/>
        <source>Version:</source>
        <translation>Verze:</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Input/wavpack/translations/wavpack_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="44"/>
        <source>WavPack Plugin</source>
        <translation>Modul WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="129"/>
        <source>About WavPack Audio Plugin</source>
        <translation>O modulu WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="130"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Vstupní modul Qmmp WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="131"/>
        <source>WavPack library version:</source>
        <translation>Verze knihovny WavPack:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="133"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="46"/>
        <source>WavPack Files</source>
        <translation>Soubory WavPack</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="73"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="68"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="75"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="198"/>
        <source>APE Tag</source>
        <translation>Tag APE</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>Cesta k souboru:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="58"/>
        <location filename="../detailsdialog.ui" line="75"/>
        <location filename="../detailsdialog.ui" line="92"/>
        <location filename="../detailsdialog.ui" line="118"/>
        <location filename="../detailsdialog.ui" line="135"/>
        <location filename="../detailsdialog.ui" line="152"/>
        <location filename="../detailsdialog.ui" line="169"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="65"/>
        <source>Sample rate:</source>
        <translation>Vzorkovací frekvence:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="82"/>
        <source>File size:</source>
        <translation>Velikost souboru:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="298"/>
        <source>Title:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="288"/>
        <source>Artist:</source>
        <translation>Umělec:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="278"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="268"/>
        <source>Comment:</source>
        <translation>Komentář:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="248"/>
        <source>Year:</source>
        <translation>Rok:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="235"/>
        <source>Track number:</source>
        <translation>Číslo stopy:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="258"/>
        <source>Genre:</source>
        <translation>Žánr:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="225"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="339"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="48"/>
        <source>Length:</source>
        <translation>Délka:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="102"/>
        <source>Channels:</source>
        <translation>Počet kanálů:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>WavPack Info</source>
        <translation>Informace WavPack</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="125"/>
        <source>Bitrate:</source>
        <translation>Datový tok:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="142"/>
        <source>Ratio:</source>
        <translation>Poměr:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="159"/>
        <source>Version:</source>
        <translation>Verze:</translation>
    </message>
</context>
</TS>
